---
title: <span class="badge builder"></span> ConnectionArgs
---
# <span class="badge builder"></span> ConnectionArgs

## Constructor

```python
ConnectionArgs()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> athena.ConnectionArgs
```

### <span class="badge object-method"></span> catalog

```python
def catalog(catalog: str) -> typing.Self
```

### <span class="badge object-method"></span> database

```python
def database(database: str) -> typing.Self
```

### <span class="badge object-method"></span> region

```python
def region(region: str) -> typing.Self
```

### <span class="badge object-method"></span> result_reuse_enabled

```python
def result_reuse_enabled(result_reuse_enabled: bool) -> typing.Self
```

### <span class="badge object-method"></span> result_reuse_max_age_in_minutes

```python
def result_reuse_max_age_in_minutes(result_reuse_max_age_in_minutes: float) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ConnectionArgs](./object-ConnectionArgs.md)
